<template>
  <el-dialog
    :visible.sync="dialogVisible"
    @close="$emit('close-dialog')"
    @closed="closed"
    @open="open"
    title="维修信息登记"
    width="1000px"
  >
    <el-form
      ref="editForm"
      :rules="rules"
      :model="formData"
      label-width="120px"
      label-suffix=":"
    >
      <el-row>
        <el-col :span="16">
          <el-form-item label="设备名称" prop="name">
            <el-input
              :clearable="false"
              v-model="formData.name"
              readonly
              disabled
            />
          </el-form-item>
        </el-col>
        <el-col :span="8">
          <el-form-item label="维修开始时间" prop="startTime">
            <el-date-picker
              type="date"
              value-format="yyyy-MM-dd"
              style="width:100%"
              placeholder="请选择维修开始时间"
              v-model="formData.startTime"
              disabled
            ></el-date-picker>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="8">
          <el-form-item label="派遣人员姓名" prop="linkName">
            <el-input
              :clearable="false"
              v-model="formData.linkName"
              disabled
            />
          </el-form-item>
        </el-col>
        <el-col :span="8">
          <el-form-item label="派遣人员电话" prop="linkPhone">
            <el-input
              :clearable="false"
              v-model="formData.linkPhone"
              disabled
            />
          </el-form-item>
        </el-col>
        <el-col :span="8">
          <el-form-item label="维修结束时间" prop="endTime">
            <el-date-picker
              type="date"
              value-format="yyyy-MM-dd"
              style="width:100%"
              placeholder="请选择维修结束时间"
              v-model="formData.endTime"
              disabled
            ></el-date-picker>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="24">
          <el-form-item label="详细地址" prop="address">
            <el-input
              disabled
              :clearable="false"
              v-model="formData.address"
              type="textarea"
              :autosize="{ minRows: 1, maxRows: 2}"
            />
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="24">
          <el-form-item label="故障描述" prop="description">
            <el-input
              disabled
              :clearable="false"
              v-model="formData.description"
              type="textarea"
              :autosize="{ minRows: 1, maxRows: 2}"
            />
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="8">
          <el-form-item label="维修人员姓名" prop="maintenanceName">
            <el-input
              :clearable="false"
              v-model="formData.maintenanceName"
              placeholder="请输入维修人员姓名"
            />
          </el-form-item>
        </el-col>
        <el-col :span="8">
          <el-form-item label="维修人员电话" prop="maintenancePhone">
            <el-input
              :clearable="false"
              v-model="formData.maintenancePhone"
              placeholder="请输入维修人员电话"
            />
          </el-form-item>
        </el-col>
        <el-col :span="8">
          <el-form-item label="实际维修时间" prop="maintenanceTime">
            <el-date-picker
              type="date"
              value-format="yyyy-MM-dd"
              style="width:100%"
              placeholder="请选择实际维修时间"
              v-model="formData.maintenanceTime"
            ></el-date-picker>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="24">
          <el-form-item label="所属部门" prop="affiliationUnitId">
            <el-cascader
              filterable
              v-model="formData.affiliationUnitId"
              :options="departmentList"
              :show-all-levels="false"
              ref="cascaderRef"
              :props="{
                label: 'name',
                value: 'id',
                children: 'children',
                emitPath:false,
                checkStrictly:true
              }"
              style="width: 100%;"
              clearable
              placeholder="请选择巡查部门"
              @change="affiliationUnitChange"
            >
            </el-cascader>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="24">
          <el-form-item label="维修内容" prop="maintenanceContent">
            <el-input
              :clearable="false"
              v-model="formData.maintenanceContent"
              type="textarea"
              :autosize="{ minRows: 1, maxRows: 2}"
              placeholder="请输入维修内容"
            />
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="24">
          <el-form-item label="是否更换零件" prop="replacementParts">
            <el-radio-group
              v-model="formData.replacementParts"
            >
              <el-radio label="1">是</el-radio>
              <el-radio label="0">否</el-radio>
            </el-radio-group>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="24">
          <el-form-item label="维修图片" prop="maintenanceImgUrlArray">
            <el-upload
              name="files"
              :action="uploadUrl"
              :headers="header"
              accept="image/jpg, image/jpeg, image/png"
              :data="{bizCode: 'Image', bizId: ''}"
              :on-success="handleAvatarSuccess"
              :before-upload="beforeAvatarUpload"
              :on-remove="handleRemove"
              :file-list="formData.maintenanceImgUrlArray"
              list-type="picture-card"
            >
              <i slot="default" class="el-icon-plus" />
            </el-upload>
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>

    <template v-slot:footer>
      <el-button
        type="primary"
        @click="handleSaveData"
      >
        保 存
      </el-button>
      <el-button @click="dialogVisible = false">取 消</el-button>
    </template>
  </el-dialog>
</template>

<script>
import {
  workOrderDetails,
  getByParentAndDemToTree,
  updateEntity
} from '@/api/device/maintenanceRepair'
import {mapState} from 'vuex'

export default {
  name: 'RepairRegistrationDialog',
  props: {
    repairRegistrationDialog: {
      default: false,
      type: Boolean
    },
    rowInfo: {
      default: () => ({}),
      type: Object
    }
  },
  computed: {
    dialogVisible: {
      get() {
        return this.repairRegistrationDialog
      },
      set(val) {
        this.$emit('update:repairRegistrationDialog', val)
      }
    },
    uploadUrl() {
      return window.context.portal + '/file/v1/fileUpload' // 服务器上传地址
    },
    previewUrl() {
      return window.context.portal + '/file/onlinePreviewController/v1/getFileById_'
    },
    ...mapState({
      header: state => {
        return {
          Authorization: `Bearer ${state.login.currentUser.token}`
        }
      }
    })
  },
  data() {
    return {
      formData: {},
      rules: {
        maintenanceName: [
          {required: true, message: '维修人员姓名不能为空', trigger: 'change'}
        ],
        maintenancePhone: [
          {required: true, message: '维修人员电话不能为空', trigger: 'change'}
        ],
        maintenanceTime: [
          {required: true, message: '实际维修时间不能为空', trigger: 'change'}
        ],
        affiliationUnitId: [
          {required: true, message: '巡查部门不能为空', trigger: 'change'}
        ],
        maintenanceContent: [
          {required: true, message: '维修内容不能为空', trigger: 'change'}
        ],
        replacementParts: [
          {required: true, message: '请选择是否更换零件', trigger: 'change'}
        ]
      },
      departmentList: [] // 设备列表
    }
  },
  created() {
    this.getDepartment()
  },
  methods: {
    // 弹层打开
    open() {
      if (this.rowInfo.id) this.getResultDetails(this.rowInfo.id)
    },

    // 弹层关闭
    closed() {
      this.formData = this.$options.data().formData
      this.$refs.editForm.resetFields()
    },

    // 获取详情
    async getResultDetails(id) {
      let {maintenanceImgUrl, ...formData} = (await workOrderDetails(id))?.value || {}
      this.formData = {
        ...formData,
        maintenanceImgUrl: (maintenanceImgUrl?.split() || []).filter(_ => _),
        maintenanceImgUrlArray: (maintenanceImgUrl?.split() || []).flatMap(id => {
          return !id ? [] : {
            url: this.previewUrl + id,
            fileId: id
          }
        })
      }
    },

    // 获得部门
    async getDepartment() {
      this.departmentList = (await getByParentAndDemToTree() || []).map(i => ({
        ...i,
        parentId: null,
        disabled: true
      }))
    },


    // 部门切换
    affiliationUnitChange(e) {
      if (!e) return
      const {value, label} = this.$refs.cascaderRef.getCheckedNodes(true)[0] || {}
      this.formData = {
        ...this.formData,
        affiliationUnit: label || '',
        affiliationUnitId: value || ''
      }
    },

    // 上传文件前
    beforeAvatarUpload(file) {
      const isJPG =
        file.type === 'image/jpeg' ||
        file.type === 'image/png' ||
        file.type === 'image/jpg'
      const isLt1M = file.size / 1024 / 1024 < 10
      if (!isJPG) {
        this.$message.error('上传图片只能是 JPG 格式!')
      }
      if (!isLt1M) {
        this.$message.error('上传图片大小不能超过 1MB!')
      }
      return isJPG && isLt1M
    },

    // 上传文件成功
    handleAvatarSuccess(res) {
      if (res.success) {
        this.formData.maintenanceImgUrl.push(res.fileId)
      } else {
        this.$message.error('上传文件失败！')
      }
    },

    // 删除文件
    handleRemove(file) {
      const index = this.formData.maintenanceImgUrl.findIndex(fileId => fileId === file.fileId)
      this.formData.maintenanceImgUrl.splice(index, 1)
    },

    // 保存
    handleSaveData() {
      this.$refs.editForm.validate(async (valid, object) => {
        if (!valid) {
          this.$message.warning(`有${Object.keys(object).length}个字段未通过校验，请正确填写表单内容。`)
        } else {
          const {maintenanceImgUrlArray, ...formData} = this.formData
          const {state} = await updateEntity({
            ...formData,
            toexamain: '4',
            maintenanceImgUrl: this.formData.maintenanceImgUrl.join(',')
          })
          if (state) {
            this.$message.success('巡检信息编辑成功')
            this.dialogVisible = false
            this.$emit('closeDialog', 'Edit')
          } else {
            this.$message.error(message + '巡检信息编辑失败')
          }
        }
      })
    }
  }
}
</script>
<style lang="scss" scoped>

</style>
